@@ -1,6 +1,6 @@
 package Pcore::App::Selenium;
 
-use Pcore qw[-class];
+use Pcore -class;
 
 extends qw[Pcore::App::Alien];
 
@@ -35,7 +35,7 @@ sub cli_name ($self) {
 }
 
 sub _build_selenium_ver ($self) {
-    return $self->cfg->{SELENIUM}->{SELENIUM_VER} // $PROC->{CFG}->{SELENIUM}->{SELENIUM_VER};
+    return $self->cfg->{SELENIUM}->{SELENIUM_VER} // $ENV->{CFG}->{SELENIUM}->{SELENIUM_VER};
 }
 
 sub _build_selenium_uri ($self) {
@@ -45,7 +45,7 @@ sub _build_selenium_uri ($self) {
 }
 
 sub _build_ff_ver ($self) {
-    return $self->cfg->{SELENIUM}->{FF_VER} // $PROC->{CFG}->{SELENIUM}->{FF_VER};
+    return $self->cfg->{SELENIUM}->{FF_VER} // $ENV->{CFG}->{SELENIUM}->{FF_VER};
 }
 
 sub _build_alien_bin_path ($self) {
@@ -68,7 +68,7 @@ sub _build_selenium ($self) {
         # NOTE on linux don't forget to install dependencies: yum install Xvfb xorg-x11-fonts*
         $self->_appx_report_info( q[Downloading: selenium-server-standalone-] . $self->selenium_ver . q[.jar] );
 
-        P->ua->mirror( $self->selenium_uri, $self->alien_bin_path, blocking => 1, on_progress => 1 );
+        P->http->mirror( $self->alien_bin_path, $self->selenium_uri, blocking => 1, on_progress => 1 );
 
         $self->_appx_report_fatal(q[Selenium deployment error]) if !-e $self->alien_bin_path;
     }
@@ -81,13 +81,15 @@ sub _build_ff ($self) {
         $self->_appx_report_warn( q["] . $self->ff_dir . q[" already exists. Remove it manually to rebuild] );
     }
     else {
-        my $uri = q[https://ftp.mozilla.org/pub/mozilla.org/firefox/releases/] . $self->ff_ver . ( $MSWIN ? q[/win32] : q[/linux-x86_64] ) . q[/en-US/];
-        $uri .= $MSWIN ? q[Firefox%20Setup%20] . $self->ff_ver . q[.exe] : q[firefox-] . $self->ff_ver . q[.tar.bz2];
-        my $store_to = $MSWIN ? $PROC->{TEMP_DIR} . 'firefox-install.exe' : $PROC->{TEMP_DIR} . 'firefox-install.tar.bz2';
+        my $uri = 'https://ftp.mozilla.org/pub/mozilla.org/firefox/releases/' . $self->ff_ver . ( $MSWIN ? '/win64' : '/linux-x86_64' ) . '/en-US/';
+
+        $uri .= $MSWIN ? 'Firefox%20Setup%20' . $self->ff_ver . '.exe' : 'firefox-' . $self->ff_ver . '.tar.bz2';
+
+        my $store_to = $MSWIN ? $ENV->{TEMP_DIR} . 'firefox-install.exe' : $ENV->{TEMP_DIR} . 'firefox-install.tar.bz2';
 
         $self->_appx_report_info( q[Downloading: ] . $uri );
 
-        P->ua->mirror( $uri, $store_to, blocking => 1, on_progress => 1 );
+        P->http->mirror( $store_to, $uri, blocking => 1, on_progress => 1 );
 
         P->file->mkpath( $self->ff_dir );
 
@@ -111,14 +113,14 @@ sub _build_ff ($self) {
 }
 
 sub _build_ff_extensions ($self) {
-    require Archive::Zip;
+    state $init = !!require Archive::Zip;
 
     my $cv = AE::cv;
 
     for my $ext ( sort keys $self->cfg->{SELENIUM}->{FF_EXTENSIONS}->%* ) {
         $self->_appx_report_info(qq[Downloading: $ext]);
 
-        P->ua->request(
+        P->http->get(
             $self->cfg->{SELENIUM}->{FF_EXTENSIONS}->{$ext},
             buf_size    => 1,
             on_progress => 1,
@@ -219,9 +221,9 @@ sub alien_proc ($self) {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 118                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
+## │    3 │ 120                  │ References::ProhibitDoubleSigils - Double-sigil dereference                                                    │
 ## ├──────┼──────────────────────┼────────────────────────────────────────────────────────────────────────────────────────────────────────────────┤
-## │    3 │ 137                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
+## │    3 │ 139                  │ ValuesAndExpressions::ProhibitInterpolationOfLiterals - Useless interpolation of literal string                │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
