@@ -51,7 +51,7 @@ sub _parse_find_element_params {
 
 sub find_element {
     my $self = shift;
-    debug( 'find element: ' . join ', ', @_ );
+    P->log->debug( 'find element: ' . join ', ', @_ );
     my $params = $self->_parse_find_element_params( \@_ );
     my $res    = try {
         return __find_element( $self, @{ $params->{driver} } );
@@ -68,9 +68,12 @@ sub find_element {
 
 sub find_elements {
     my $self = shift;
-    debug( 'find elements: ' . join ', ', @_ );
+
+    P->log->debug( 'find elements: ' . join ', ', @_ );
+
     my $params = $self->_parse_find_element_params( \@_ );
-    my $res    = try {
+
+    my $res = try {
         return __find_elements( $self, @{ $params->{driver} } );
     }
     catch {
@@ -91,27 +94,36 @@ sub find_elements {
 sub find_child_element {
     my $self   = shift;
     my $parent = shift;
-    debug( 'find child element: ' . join ', ', @_ );
+
+    P->log->debug( 'find child element: ' . join ', ', @_ );
+
     my $params = $self->_parse_find_element_params( \@_ );
-    my $res    = try {
+
+    my $res = try {
         return \&__find_child_element( $self, $parent, @{ $params->{driver} } );
     }
     catch {
         my $err = $@;
+
         $self->implicit_wait_timeout( $params->{timeout} ) if defined $params->{timeout};
+
         die $err;
     };
 
     $self->implicit_wait_timeout( $params->{timeout} ) if defined $params->{timeout};
+
     return ${$res};
 }
 
 sub find_child_elements {
     my $self   = shift;
     my $parent = shift;
-    debug( 'find child elements: ' . join ', ', @_ );
+
+    P->log->debug( 'find child elements: ' . join ', ', @_ );
+
     my $params = $self->_parse_find_element_params( \@_ );
-    my $res    = try {
+
+    my $res = try {
         return \&__find_element( $self, $parent, @{ $params->{driver} } );
     }
     catch {
@@ -239,8 +251,10 @@ sub screenshot {
     my $screenshot = P->data->from_b64( $self->_execute_command($res) );
 
     if ( $args{left} || $args{top} || $args{right} || $args{bottom} || $args{width} || $args{height} ) {
-        require Imager;
+        state $init = !!require Imager;
+
         my $img = Imager->new;
+
         $img->read( data => $screenshot, type => 'png' );
 
         my %params = (
@@ -405,7 +419,7 @@ sub DESTROY {
 
     if ( defined $self->{session_id} ) {
         if ( ${^GLOBAL_PHASE} eq 'DESTRUCT' ) {
-            P->ua->request( DELETE => 'http://' . $self->{remote_server_addr} . q[:] . $self->{port} . '/wd/hub/session/' . $self->{session_id} );
+            P->http->delete( 'http://' . $self->{remote_server_addr} . q[:] . $self->{port} . '/wd/hub/session/' . $self->{session_id} );
         }
         else {
             $self->quit() if $self->{auto_close};
@@ -421,7 +435,7 @@ sub DESTROY {
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    3 │ 341                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_get_binary_data' declared but not  │
+## │    3 │ 355                  │ Subroutines::ProhibitUnusedPrivateSubroutines - Private subroutine/method '_get_binary_data' declared but not  │
 ## │      │                      │ used                                                                                                           │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
