@@ -119,10 +119,14 @@ sub get_image {
 JS
             my $data = $self->{driver}->execute_script( $js, $self );
 
-            require Imager;
-            my $x   = 0;
-            my $y   = 0;
+            state $init = !!require Imager;
+
+            my $x = 0;
+
+            my $y = 0;
+
             my $img = Imager->new( xsize => $data->{width}, ysize => $data->{height} );
+
             for ( my $i = 0; $i <= $#{ $data->{data} }; $i += 4 ) {
                 $img->setpixel( x => $x, y => $y, color => Imager::Color->new( $data->{data}->[$i], $data->{data}->[ $i + 1 ], $data->{data}->[ $i + 2 ], $data->{data}->[ $i + 3 ] ) );
                 if ( ++$x == $data->{width} ) {
@@ -147,7 +151,7 @@ JS
 ## ┌──────┬──────────────────────┬────────────────────────────────────────────────────────────────────────────────────────────────────────────────┐
 ## │ Sev. │ Lines                │ Policy                                                                                                         │
 ## ╞══════╪══════════════════════╪════════════════════════════════════════════════════════════════════════════════════════════════════════════════╡
-## │    2 │ 126                  │ ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            │
+## │    2 │ 130                  │ ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            │
 ## └──────┴──────────────────────┴────────────────────────────────────────────────────────────────────────────────────────────────────────────────┘
 ##
 ## -----SOURCE FILTER LOG END-----
